# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/listing/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/listing/query.proto\x12\x14\x64ydxprotocol.listing\"\x15\n\x13QueryMarketsHardCap\"/\n\x1bQueryMarketsHardCapResponse\x12\x10\n\x08hard_cap\x18\x01 \x01(\r2w\n\x05Query\x12n\n\x0eMarketsHardCap\x12).dydxprotocol.listing.QueryMarketsHardCap\x1a\x31.dydxprotocol.listing.QueryMarketsHardCapResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_QUERYMARKETSHARDCAP']._serialized_start=58
  _globals['_QUERYMARKETSHARDCAP']._serialized_end=79
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_start=81
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_end=128
  _globals['_QUERY']._serialized_start=130
  _globals['_QUERY']._serialized_end=249
# @@protoc_insertion_point(module_scope)
