# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/assets/asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/assets/asset.proto\x12\x13\x64ydxprotocol.assets\"\x8c\x01\n\x05\x41sset\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x65nom_exponent\x18\x04 \x01(\x11\x12\x12\n\nhas_market\x18\x05 \x01(\x08\x12\x11\n\tmarket_id\x18\x06 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.assets.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/types'
  _globals['_ASSET']._serialized_start=57
  _globals['_ASSET']._serialized_end=197
# @@protoc_insertion_point(module_scope)
