# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/subaccounts/streaming.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/subaccounts/streaming.proto\x12\x18\x64ydxprotocol.subaccounts\x1a)dydxprotocol/subaccounts/subaccount.proto\"\x99\x02\n\x16StreamSubaccountUpdate\x12=\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12Z\n\x1bupdated_perpetual_positions\x18\x02 \x03(\x0b\x32\x35.dydxprotocol.subaccounts.SubaccountPerpetualPosition\x12R\n\x17updated_asset_positions\x18\x03 \x03(\x0b\x32\x31.dydxprotocol.subaccounts.SubaccountAssetPosition\x12\x10\n\x08snapshot\x18\x04 \x01(\x08\"E\n\x1bSubaccountPerpetualPosition\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x10\n\x08quantums\x18\x02 \x01(\x04\"=\n\x17SubaccountAssetPosition\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\r\x12\x10\n\x08quantums\x18\x02 \x01(\x04\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.streaming_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _globals['_STREAMSUBACCOUNTUPDATE']._serialized_start=114
  _globals['_STREAMSUBACCOUNTUPDATE']._serialized_end=395
  _globals['_SUBACCOUNTPERPETUALPOSITION']._serialized_start=397
  _globals['_SUBACCOUNTPERPETUALPOSITION']._serialized_end=466
  _globals['_SUBACCOUNTASSETPOSITION']._serialized_start=468
  _globals['_SUBACCOUNTASSETPOSITION']._serialized_end=529
# @@protoc_insertion_point(module_scope)
