# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/feetiers/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.feetiers import params_pb2 as dydxprotocol_dot_feetiers_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/feetiers/query.proto\x12\x15\x64ydxprotocol.feetiers\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/feetiers/params.proto\" \n\x1eQueryPerpetualFeeParamsRequest\"b\n\x1fQueryPerpetualFeeParamsResponse\x12?\n\x06params\x18\x01 \x01(\x0b\x32).dydxprotocol.feetiers.PerpetualFeeParamsB\x04\xc8\xde\x1f\x00\"A\n\x17QueryUserFeeTierRequest\x12&\n\x04user\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"`\n\x18QueryUserFeeTierResponse\x12\r\n\x05index\x18\x01 \x01(\r\x12\x35\n\x04tier\x18\x02 \x01(\x0b\x32\'.dydxprotocol.feetiers.PerpetualFeeTier2\xe7\x02\n\x05Query\x12\xbb\x01\n\x12PerpetualFeeParams\x12\x35.dydxprotocol.feetiers.QueryPerpetualFeeParamsRequest\x1a\x36.dydxprotocol.feetiers.QueryPerpetualFeeParamsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/v4/feetiers/perpetual_fee_params\x12\x9f\x01\n\x0bUserFeeTier\x12..dydxprotocol.feetiers.QueryUserFeeTierRequest\x1a/.dydxprotocol.feetiers.QueryUserFeeTierResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/v4/feetiers/user_fee_tierB<Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.feetiers.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/types'
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUSERFEETIERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_QUERYUSERFEETIERREQUEST'].fields_by_name['user']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['PerpetualFeeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualFeeParams']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/v4/feetiers/perpetual_fee_params'
  _globals['_QUERY'].methods_by_name['UserFeeTier']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserFeeTier']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/v4/feetiers/user_fee_tier'
  _globals['_QUERYPERPETUALFEEPARAMSREQUEST']._serialized_start=175
  _globals['_QUERYPERPETUALFEEPARAMSREQUEST']._serialized_end=207
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE']._serialized_start=209
  _globals['_QUERYPERPETUALFEEPARAMSRESPONSE']._serialized_end=307
  _globals['_QUERYUSERFEETIERREQUEST']._serialized_start=309
  _globals['_QUERYUSERFEETIERREQUEST']._serialized_end=374
  _globals['_QUERYUSERFEETIERRESPONSE']._serialized_start=376
  _globals['_QUERYUSERFEETIERRESPONSE']._serialized_end=472
  _globals['_QUERY']._serialized_start=475
  _globals['_QUERY']._serialized_end=834
# @@protoc_insertion_point(module_scope)
