# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/blocktime/blocktime.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/blocktime/blocktime.proto\x12\x16\x64ydxprotocol.blocktime\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"T\n\tBlockInfo\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\x37\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xdb\x01\n\x0f\x41llDowntimeInfo\x12\x43\n\x05infos\x18\x01 \x03(\x0b\x32\x34.dydxprotocol.blocktime.AllDowntimeInfo.DowntimeInfo\x1a\x82\x01\n\x0c\x44owntimeInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12;\n\nblock_info\x18\x02 \x01(\x0b\x32!.dydxprotocol.blocktime.BlockInfoB\x04\xc8\xde\x1f\x00\x42=Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.blocktime.blocktime_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/types'
  _globals['_BLOCKINFO'].fields_by_name['timestamp']._loaded_options = None
  _globals['_BLOCKINFO'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['block_info']._loaded_options = None
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO'].fields_by_name['block_info']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKINFO']._serialized_start=153
  _globals['_BLOCKINFO']._serialized_end=237
  _globals['_ALLDOWNTIMEINFO']._serialized_start=240
  _globals['_ALLDOWNTIMEINFO']._serialized_end=459
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO']._serialized_start=329
  _globals['_ALLDOWNTIMEINFO_DOWNTIMEINFO']._serialized_end=459
# @@protoc_insertion_point(module_scope)
