# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/listing/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/listing/tx.proto\x12\x14\x64ydxprotocol.listing\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"q\n\x14MsgSetMarketsHardCap\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x1c\n\x14hard_cap_for_markets\x18\x02 \x01(\r:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgSetMarketsHardCapResponse\"\xe4\x01\n\x1dMsgCreateMarketPermissionless\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12=\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\'\n%MsgCreateMarketPermissionlessResponse2\x8b\x02\n\x03Msg\x12s\n\x11SetMarketsHardCap\x12*.dydxprotocol.listing.MsgSetMarketsHardCap\x1a\x32.dydxprotocol.listing.MsgSetMarketsHardCapResponse\x12\x8e\x01\n\x1a\x43reateMarketPermissionless\x12\x33.dydxprotocol.listing.MsgCreateMarketPermissionless\x1a;.dydxprotocol.listing.MsgCreateMarketPermissionlessResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_MSGSETMARKETSHARDCAP'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETSHARDCAP'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETSHARDCAP']._loaded_options = None
  _globals['_MSGSETMARKETSHARDCAP']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEMARKETPERMISSIONLESS'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGCREATEMARKETPERMISSIONLESS'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._loaded_options = None
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGSETMARKETSHARDCAP']._serialized_start=172
  _globals['_MSGSETMARKETSHARDCAP']._serialized_end=285
  _globals['_MSGSETMARKETSHARDCAPRESPONSE']._serialized_start=287
  _globals['_MSGSETMARKETSHARDCAPRESPONSE']._serialized_end=317
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_start=320
  _globals['_MSGCREATEMARKETPERMISSIONLESS']._serialized_end=548
  _globals['_MSGCREATEMARKETPERMISSIONLESSRESPONSE']._serialized_start=550
  _globals['_MSGCREATEMARKETPERMISSIONLESSRESPONSE']._serialized_end=589
  _globals['_MSG']._serialized_start=592
  _globals['_MSG']._serialized_end=859
# @@protoc_insertion_point(module_scope)
