# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/block_rate_limit_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/dydxprotocol/clob/block_rate_limit_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xac\x03\n\x1b\x42lockRateLimitConfiguration\x12]\n\"max_short_term_orders_per_n_blocks\x18\x01 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x06\x18\x01\xc8\xde\x1f\x00\x12Y\n max_stateful_orders_per_n_blocks\x18\x02 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x04\xc8\xde\x1f\x00\x12j\n/max_short_term_order_cancellations_per_n_blocks\x18\x03 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x06\x18\x01\xc8\xde\x1f\x00\x12g\n.max_short_term_orders_and_cancels_per_n_blocks\x18\x04 \x03(\x0b\x32).dydxprotocol.clob.MaxPerNBlocksRateLimitB\x04\xc8\xde\x1f\x00\";\n\x16MaxPerNBlocksRateLimit\x12\x12\n\nnum_blocks\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.block_rate_limit_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_per_n_blocks']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_stateful_orders_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_stateful_orders_per_n_blocks']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_order_cancellations_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_order_cancellations_per_n_blocks']._serialized_options = b'\030\001\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_and_cancels_per_n_blocks']._loaded_options = None
  _globals['_BLOCKRATELIMITCONFIGURATION'].fields_by_name['max_short_term_orders_and_cancels_per_n_blocks']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKRATELIMITCONFIGURATION']._serialized_start=93
  _globals['_BLOCKRATELIMITCONFIGURATION']._serialized_end=521
  _globals['_MAXPERNBLOCKSRATELIMIT']._serialized_start=523
  _globals['_MAXPERNBLOCKSRATELIMIT']._serialized_end=582
# @@protoc_insertion_point(module_scope)
