# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64ydxprotocol/vault/tx.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\x1a\x14gogoproto/gogo.proto\"\xf7\x01\n\x11MsgDepositToVault\x12-\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultId\x12=\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\x1b\n\x19MsgDepositToVaultResponse\"\xa5\x01\n\x1dMsgUpdateDefaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x02 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\'\n%MsgUpdateDefaultQuotingParamsResponse\"\xcd\x01\n\x18MsgSetVaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12?\n\x0equoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\"\n MsgSetVaultQuotingParamsResponse2\xf7\x02\n\x03Msg\x12\x66\n\x0e\x44\x65positToVault\x12%.dydxprotocol.vault.MsgDepositToVault\x1a-.dydxprotocol.vault.MsgDepositToVaultResponse\x12\x8a\x01\n\x1aUpdateDefaultQuotingParams\x12\x31.dydxprotocol.vault.MsgUpdateDefaultQuotingParams\x1a\x39.dydxprotocol.vault.MsgUpdateDefaultQuotingParamsResponse\x12{\n\x15SetVaultQuotingParams\x12,.dydxprotocol.vault.MsgSetVaultQuotingParams\x1a\x34.dydxprotocol.vault.MsgSetVaultQuotingParamsResponseB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_MSGDEPOSITTOVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGDEPOSITTOVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGDEPOSITTOVAULT']._loaded_options = None
  _globals['_MSGDEPOSITTOVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDEPOSITTOVAULT']._serialized_start=234
  _globals['_MSGDEPOSITTOVAULT']._serialized_end=481
  _globals['_MSGDEPOSITTOVAULTRESPONSE']._serialized_start=483
  _globals['_MSGDEPOSITTOVAULTRESPONSE']._serialized_end=510
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_start=513
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_end=678
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_start=680
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_end=719
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_start=722
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_end=927
  _globals['_MSGSETVAULTQUOTINGPARAMSRESPONSE']._serialized_start=929
  _globals['_MSGSETVAULTQUOTINGPARAMSRESPONSE']._serialized_end=963
  _globals['_MSG']._serialized_start=966
  _globals['_MSG']._serialized_end=1341
# @@protoc_insertion_point(module_scope)
