# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/blocktime/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.blocktime import params_pb2 as dydxprotocol_dot_blocktime_dot_params__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/blocktime/tx.proto\x12\x16\x64ydxprotocol.blocktime\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a#dydxprotocol/blocktime/params.proto\x1a\x14gogoproto/gogo.proto\"\x94\x01\n\x17MsgUpdateDowntimeParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x06params\x18\x02 \x01(\x0b\x32&.dydxprotocol.blocktime.DowntimeParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"!\n\x1fMsgUpdateDowntimeParamsResponse2\x88\x01\n\x03Msg\x12\x80\x01\n\x14UpdateDowntimeParams\x12/.dydxprotocol.blocktime.MsgUpdateDowntimeParams\x1a\x37.dydxprotocol.blocktime.MsgUpdateDowntimeParamsResponseB=Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.blocktime.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/blocktime/types'
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_start=171
  _globals['_MSGUPDATEDOWNTIMEPARAMS']._serialized_end=319
  _globals['_MSGUPDATEDOWNTIMEPARAMSRESPONSE']._serialized_start=321
  _globals['_MSGUPDATEDOWNTIMEPARAMSRESPONSE']._serialized_end=354
  _globals['_MSG']._serialized_start=357
  _globals['_MSG']._serialized_end=493
# @@protoc_insertion_point(module_scope)
