# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vest/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as dydxprotocol_dot_vest_dot_vest__entry__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64ydxprotocol/vest/tx.proto\x12\x11\x64ydxprotocol.vest\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\"dydxprotocol/vest/vest_entry.proto\x1a\x14gogoproto/gogo.proto\"i\n\x12MsgDeleteVestEntry\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x16\n\x0evester_account\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgDeleteVestEntryResponse\"\x81\x01\n\x0fMsgSetVestEntry\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x31\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x1c.dydxprotocol.vest.VestEntryB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgSetVestEntryResponse2\xce\x01\n\x03Msg\x12^\n\x0cSetVestEntry\x12\".dydxprotocol.vest.MsgSetVestEntry\x1a*.dydxprotocol.vest.MsgSetVestEntryResponse\x12g\n\x0f\x44\x65leteVestEntry\x12%.dydxprotocol.vest.MsgDeleteVestEntry\x1a-.dydxprotocol.vest.MsgDeleteVestEntryResponseB8Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_MSGDELETEVESTENTRY'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGDELETEVESTENTRY'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDELETEVESTENTRY']._loaded_options = None
  _globals['_MSGDELETEVESTENTRY']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVESTENTRY'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVESTENTRY'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVESTENTRY'].fields_by_name['entry']._loaded_options = None
  _globals['_MSGSETVESTENTRY'].fields_by_name['entry']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVESTENTRY']._loaded_options = None
  _globals['_MSGSETVESTENTRY']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDELETEVESTENTRY']._serialized_start=159
  _globals['_MSGDELETEVESTENTRY']._serialized_end=264
  _globals['_MSGDELETEVESTENTRYRESPONSE']._serialized_start=266
  _globals['_MSGDELETEVESTENTRYRESPONSE']._serialized_end=294
  _globals['_MSGSETVESTENTRY']._serialized_start=297
  _globals['_MSGSETVESTENTRY']._serialized_end=426
  _globals['_MSGSETVESTENTRYRESPONSE']._serialized_start=428
  _globals['_MSGSETVESTENTRYRESPONSE']._serialized_end=453
  _globals['_MSG']._serialized_start=456
  _globals['_MSG']._serialized_end=662
# @@protoc_insertion_point(module_scope)
