# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/accountplus/accountplus.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*dydxprotocol/accountplus/accountplus.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\"w\n\x0c\x41\x63\x63ountState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12V\n\x17timestamp_nonce_details\x18\x02 \x01(\x0b\x32/.dydxprotocol.accountplus.TimestampNonceDetailsB\x04\xc8\xde\x1f\x00\"L\n\x15TimestampNonceDetails\x12\x18\n\x10timestamp_nonces\x18\x01 \x03(\x04\x12\x19\n\x11max_ejected_nonce\x18\x02 \x01(\x04\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.accountplus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_ACCOUNTSTATE'].fields_by_name['timestamp_nonce_details']._loaded_options = None
  _globals['_ACCOUNTSTATE'].fields_by_name['timestamp_nonce_details']._serialized_options = b'\310\336\037\000'
  _globals['_ACCOUNTSTATE']._serialized_start=94
  _globals['_ACCOUNTSTATE']._serialized_end=213
  _globals['_TIMESTAMPNONCEDETAILS']._serialized_start=215
  _globals['_TIMESTAMPNONCEDETAILS']._serialized_end=291
# @@protoc_insertion_point(module_scope)
