# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/order.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.clob import liquidations_pb2 as dydxprotocol_dot_clob_dot_liquidations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/clob/order.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a$dydxprotocol/clob/liquidations.proto\"\x8c\x01\n\x07OrderId\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x11\n\tclient_id\x18\x02 \x01(\x07\x12\x13\n\x0border_flags\x18\x03 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x04 \x01(\r\"T\n\x1dOrdersFilledDuringLatestBlock\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"P\n\x19PotentiallyPrunableOrders\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"D\n\x0eOrderFillState\x12\x13\n\x0b\x66ill_amount\x18\x01 \x01(\x04\x12\x1d\n\x15prunable_block_height\x18\x02 \x01(\r\"R\n\x1bStatefulOrderTimeSliceValue\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"\x8e\x01\n\x16LongTermOrderPlacement\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x45\n\x0fplacement_index\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrderingB\x04\xc8\xde\x1f\x00\"\xd0\x01\n\x19\x43onditionalOrderPlacement\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x45\n\x0fplacement_index\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrderingB\x04\xc8\xde\x1f\x00\x12=\n\rtrigger_index\x18\x03 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrdering\"\xdf\x05\n\x05Order\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12+\n\x04side\x18\x02 \x01(\x0e\x32\x1d.dydxprotocol.clob.Order.Side\x12\x10\n\x08quantums\x18\x03 \x01(\x04\x12\x10\n\x08subticks\x18\x04 \x01(\x04\x12\x18\n\x0egood_til_block\x18\x05 \x01(\rH\x00\x12\x1d\n\x13good_til_block_time\x18\x06 \x01(\x07H\x00\x12;\n\rtime_in_force\x18\x07 \x01(\x0e\x32$.dydxprotocol.clob.Order.TimeInForce\x12\x13\n\x0breduce_only\x18\x08 \x01(\x08\x12\x17\n\x0f\x63lient_metadata\x18\t \x01(\r\x12>\n\x0e\x63ondition_type\x18\n \x01(\x0e\x32&.dydxprotocol.clob.Order.ConditionType\x12*\n\"conditional_order_trigger_subticks\x18\x0b \x01(\x04\"9\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BUY\x10\x01\x12\r\n\tSIDE_SELL\x10\x02\"\x84\x01\n\x0bTimeInForce\x12\x1d\n\x19TIME_IN_FORCE_UNSPECIFIED\x10\x00\x12\x15\n\x11TIME_IN_FORCE_IOC\x10\x01\x12\x1b\n\x17TIME_IN_FORCE_POST_ONLY\x10\x02\x12\"\n\x1aTIME_IN_FORCE_FILL_OR_KILL\x10\x03\x1a\x02\x08\x01\"m\n\rConditionType\x12\x1e\n\x1a\x43ONDITION_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONDITION_TYPE_STOP_LOSS\x10\x01\x12\x1e\n\x1a\x43ONDITION_TYPE_TAKE_PROFIT\x10\x02\x42\x10\n\x0egood_til_oneof\"F\n\x13TransactionOrdering\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\r\x12\x19\n\x11transaction_index\x18\x02 \x01(\r\"\xa9\x01\n\x16StreamLiquidationOrder\x12\x45\n\x10liquidation_info\x18\x01 \x01(\x0b\x32+.dydxprotocol.clob.PerpetualLiquidationInfo\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06is_buy\x18\x03 \x01(\x08\x12\x10\n\x08quantums\x18\x04 \x01(\x04\x12\x10\n\x08subticks\x18\x05 \x01(\x04\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_ORDERID'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_ORDERID'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK'].fields_by_name['order_ids']._loaded_options = None
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_POTENTIALLYPRUNABLEORDERS'].fields_by_name['order_ids']._loaded_options = None
  _globals['_POTENTIALLYPRUNABLEORDERS'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_STATEFULORDERTIMESLICEVALUE'].fields_by_name['order_ids']._loaded_options = None
  _globals['_STATEFULORDERTIMESLICEVALUE'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['order']._loaded_options = None
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['placement_index']._loaded_options = None
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['placement_index']._serialized_options = b'\310\336\037\000'
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['order']._loaded_options = None
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['placement_index']._loaded_options = None
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['placement_index']._serialized_options = b'\310\336\037\000'
  _globals['_ORDER_TIMEINFORCE'].values_by_name["TIME_IN_FORCE_FILL_OR_KILL"]._loaded_options = None
  _globals['_ORDER_TIMEINFORCE'].values_by_name["TIME_IN_FORCE_FILL_OR_KILL"]._serialized_options = b'\010\001'
  _globals['_ORDER'].fields_by_name['order_id']._loaded_options = None
  _globals['_ORDER'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERID']._serialized_start=156
  _globals['_ORDERID']._serialized_end=296
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK']._serialized_start=298
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK']._serialized_end=382
  _globals['_POTENTIALLYPRUNABLEORDERS']._serialized_start=384
  _globals['_POTENTIALLYPRUNABLEORDERS']._serialized_end=464
  _globals['_ORDERFILLSTATE']._serialized_start=466
  _globals['_ORDERFILLSTATE']._serialized_end=534
  _globals['_STATEFULORDERTIMESLICEVALUE']._serialized_start=536
  _globals['_STATEFULORDERTIMESLICEVALUE']._serialized_end=618
  _globals['_LONGTERMORDERPLACEMENT']._serialized_start=621
  _globals['_LONGTERMORDERPLACEMENT']._serialized_end=763
  _globals['_CONDITIONALORDERPLACEMENT']._serialized_start=766
  _globals['_CONDITIONALORDERPLACEMENT']._serialized_end=974
  _globals['_ORDER']._serialized_start=977
  _globals['_ORDER']._serialized_end=1712
  _globals['_ORDER_SIDE']._serialized_start=1391
  _globals['_ORDER_SIDE']._serialized_end=1448
  _globals['_ORDER_TIMEINFORCE']._serialized_start=1451
  _globals['_ORDER_TIMEINFORCE']._serialized_end=1583
  _globals['_ORDER_CONDITIONTYPE']._serialized_start=1585
  _globals['_ORDER_CONDITIONTYPE']._serialized_end=1694
  _globals['_TRANSACTIONORDERING']._serialized_start=1714
  _globals['_TRANSACTIONORDERING']._serialized_end=1784
  _globals['_STREAMLIQUIDATIONORDER']._serialized_start=1787
  _globals['_STREAMLIQUIDATIONORDER']._serialized_end=1956
# @@protoc_insertion_point(module_scope)
