# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/revshare/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/revshare/query.proto\x12\x15\x64ydxprotocol.revshare\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"%\n#QueryMarketMapperRevenueShareParams\"z\n+QueryMarketMapperRevenueShareParamsResponse\x12K\n\x06params\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00\"5\n QueryMarketMapperRevShareDetails\x12\x11\n\tmarket_id\x18\x01 \x01(\r\"u\n(QueryMarketMapperRevShareDetailsResponse\x12I\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00\x32\xcf\x03\n\x05Query\x12\xdf\x01\n\x1eMarketMapperRevenueShareParams\x12:.dydxprotocol.revshare.QueryMarketMapperRevenueShareParams\x1a\x42.dydxprotocol.revshare.QueryMarketMapperRevenueShareParamsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dydxprotocol/revshare/market_mapper_rev_share_params\x12\xe3\x01\n\x1bMarketMapperRevShareDetails\x12\x37.dydxprotocol.revshare.QueryMarketMapperRevShareDetails\x1a?.dydxprotocol.revshare.QueryMarketMapperRevShareDetailsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._serialized_options = b'\202\323\344\223\0027\0225/dydxprotocol/revshare/market_mapper_rev_share_params'
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._serialized_options = b'\202\323\344\223\002D\022B/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_start=186
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_end=223
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_start=225
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_end=347
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_start=349
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_end=402
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_start=404
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_end=521
  _globals['_QUERY']._serialized_start=524
  _globals['_QUERY']._serialized_end=987
# @@protoc_insertion_point(module_scope)
