# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/events/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as dydxprotocol_dot_indexer_dot_shared_dot_removal__reason__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_clob__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import perpetual_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_perpetual__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/indexer/events/events.proto\x12\x1b\x64ydxprotocol.indexer.events\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x30\x64ydxprotocol/indexer/shared/removal_reason.proto\x1a+dydxprotocol/indexer/protocol/v1/clob.proto\x1a\x30\x64ydxprotocol/indexer/protocol/v1/perpetual.proto\x1a\x31\x64ydxprotocol/indexer/protocol/v1/subaccount.proto\"\xa3\x01\n\x0f\x46undingUpdateV1\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x19\n\x11\x66unding_value_ppm\x18\x02 \x01(\x05\x12_\n\rfunding_index\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\x84\x02\n\x0e\x46undingEventV1\x12\x43\n\x07updates\x18\x01 \x03(\x0b\x32,.dydxprotocol.indexer.events.FundingUpdateV1B\x04\xc8\xde\x1f\x00\x12>\n\x04type\x18\x02 \x01(\x0e\x32\x30.dydxprotocol.indexer.events.FundingEventV1.Type\"m\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13TYPE_PREMIUM_SAMPLE\x10\x01\x12\x1f\n\x1bTYPE_FUNDING_RATE_AND_INDEX\x10\x02\x12\x15\n\x11TYPE_PREMIUM_VOTE\x10\x03\"\x90\x02\n\rMarketEventV1\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12M\n\x0cprice_update\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.events.MarketPriceUpdateEventV1H\x00\x12I\n\rmarket_create\x18\x03 \x01(\x0b\x32\x30.dydxprotocol.indexer.events.MarketCreateEventV1H\x00\x12I\n\rmarket_modify\x18\x04 \x01(\x0b\x32\x30.dydxprotocol.indexer.events.MarketModifyEventV1H\x00\x42\x07\n\x05\x65vent\"7\n\x18MarketPriceUpdateEventV1\x12\x1b\n\x13price_with_exponent\x18\x01 \x01(\x04\"?\n\x11MarketBaseEventV1\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x1c\n\x14min_price_change_ppm\x18\x02 \x01(\r\"e\n\x13MarketCreateEventV1\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.events.MarketBaseEventV1\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x11\"S\n\x13MarketModifyEventV1\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.events.MarketBaseEventV1\"\x96\x01\n\rSourceOfFunds\x12N\n\rsubaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdH\x00\x12+\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringH\x00\x42\x08\n\x06source\"\xdb\x02\n\x0fTransferEventV1\x12S\n\x14sender_subaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12V\n\x17recipient_subaccount_id\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12\x10\n\x08\x61sset_id\x18\x03 \x01(\r\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12:\n\x06sender\x18\x05 \x01(\x0b\x32*.dydxprotocol.indexer.events.SourceOfFunds\x12=\n\trecipient\x18\x06 \x01(\x0b\x32*.dydxprotocol.indexer.events.SourceOfFunds\"\xee\x02\n\x10OrderFillEventV1\x12I\n\x0bmaker_order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderB\x04\xc8\xde\x1f\x00\x12?\n\x05order\x18\x02 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderH\x00\x12L\n\x11liquidation_order\x18\x04 \x01(\x0b\x32/.dydxprotocol.indexer.events.LiquidationOrderV1H\x00\x12\x13\n\x0b\x66ill_amount\x18\x03 \x01(\x04\x12\x11\n\tmaker_fee\x18\x05 \x01(\x12\x12\x11\n\ttaker_fee\x18\x06 \x01(\x12\x12\x1a\n\x12total_filled_maker\x18\x07 \x01(\x04\x12\x1a\n\x12total_filled_taker\x18\x08 \x01(\x04\x42\r\n\x0btaker_order\"\xad\x02\n\x13\x44\x65leveragingEventV1\x12O\n\nliquidated\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12O\n\noffsetting\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cperpetual_id\x18\x03 \x01(\r\x12\x13\n\x0b\x66ill_amount\x18\x04 \x01(\x04\x12\x1c\n\x14total_quote_quantums\x18\x05 \x01(\x04\x12\x0e\n\x06is_buy\x18\x06 \x01(\x08\x12\x1b\n\x13is_final_settlement\x18\x07 \x01(\x08\"\xc7\x01\n\x12LiquidationOrderV1\x12O\n\nliquidated\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x14\n\x0cperpetual_id\x18\x03 \x01(\r\x12\x12\n\ntotal_size\x18\x04 \x01(\x04\x12\x0e\n\x06is_buy\x18\x05 \x01(\x08\x12\x10\n\x08subticks\x18\x06 \x01(\x04\"\xa7\x02\n\x17SubaccountUpdateEventV1\x12L\n\rsubaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12_\n\x1bupdated_perpetual_positions\x18\x03 \x03(\x0b\x32:.dydxprotocol.indexer.protocol.v1.IndexerPerpetualPosition\x12W\n\x17updated_asset_positions\x18\x04 \x03(\x0b\x32\x36.dydxprotocol.indexer.protocol.v1.IndexerAssetPositionJ\x04\x08\x02\x10\x03\"\x8c\x0b\n\x14StatefulOrderEventV1\x12\x65\n\x0border_place\x18\x01 \x01(\x0b\x32J.dydxprotocol.indexer.events.StatefulOrderEventV1.StatefulOrderPlacementV1B\x02\x18\x01H\x00\x12\x61\n\rorder_removal\x18\x04 \x01(\x0b\x32H.dydxprotocol.indexer.events.StatefulOrderEventV1.StatefulOrderRemovalV1H\x00\x12t\n\x1b\x63onditional_order_placement\x18\x05 \x01(\x0b\x32M.dydxprotocol.indexer.events.StatefulOrderEventV1.ConditionalOrderPlacementV1H\x00\x12t\n\x1b\x63onditional_order_triggered\x18\x06 \x01(\x0b\x32M.dydxprotocol.indexer.events.StatefulOrderEventV1.ConditionalOrderTriggeredV1H\x00\x12o\n\x19long_term_order_placement\x18\x07 \x01(\x0b\x32J.dydxprotocol.indexer.events.StatefulOrderEventV1.LongTermOrderPlacementV1H\x00\x12i\n\x11order_replacement\x18\x08 \x01(\x0b\x32L.dydxprotocol.indexer.events.StatefulOrderEventV1.LongTermOrderReplacementV1H\x00\x1aY\n\x18StatefulOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1a\xa5\x01\n\x16StatefulOrderRemovalV1\x12J\n\x10removed_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.dydxprotocol.indexer.shared.OrderRemovalReason\x1a\\\n\x1b\x43onditionalOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1ak\n\x1b\x43onditionalOrderTriggeredV1\x12L\n\x12triggered_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x1aY\n\x18LongTermOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1a\xa3\x01\n\x1aLongTermOrderReplacementV1\x12\x46\n\x0cold_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12=\n\x05order\x18\x02 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderB\x07\n\x05\x65ventJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"r\n\x12\x41ssetCreateEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x12\n\nhas_market\x18\x03 \x01(\x08\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x05 \x01(\x11\"\xb8\x02\n\x1cPerpetualMarketCreateEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x08 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\t \x01(\x04\x12\x16\n\x0eliquidity_tier\x18\n \x01(\r:\x02\x18\x01\"\x80\x03\n\x1cPerpetualMarketCreateEventV2\x12\n\n\x02id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x08 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\t \x01(\x04\x12\x16\n\x0eliquidity_tier\x18\n \x01(\r\x12J\n\x0bmarket_type\x18\x0b \x01(\x0e\x32\x35.dydxprotocol.indexer.protocol.v1.PerpetualMarketType\"\xd6\x01\n\x1aLiquidityTierUpsertEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08R\x17open_interest_lower_capR\x17open_interest_upper_cap\"\xcb\x01\n\x15UpdateClobPairEventV1\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12@\n\x06status\x18\x02 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x03 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x04 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\x05 \x01(\x04\"z\n\x16UpdatePerpetualEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x04 \x01(\x11\x12\x16\n\x0eliquidity_tier\x18\x05 \x01(\r\"c\n\x15TradingRewardsEventV1\x12J\n\x0ftrading_rewards\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.indexer.events.AddressTradingReward\"\x85\x01\n\x14\x41\x64\x64ressTradingReward\x12\r\n\x05owner\x18\x01 \x01(\t\x12^\n\x0c\x64\x65nom_amount\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"k\n\x19OpenInterestUpdateEventV1\x12N\n\x15open_interest_updates\x18\x01 \x03(\x0b\x32/.dydxprotocol.indexer.events.OpenInterestUpdate\"\x8b\x01\n\x12OpenInterestUpdate\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12_\n\ropen_interest\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xda\x01\n\x1aLiquidityTierUpsertEventV2\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01\x12\x1f\n\x17open_interest_lower_cap\x18\x06 \x01(\x04\x12\x1f\n\x17open_interest_upper_cap\x18\x07 \x01(\x04\x42:Z8github.com/dydxprotocol/v4-chain/protocol/indexer/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.events.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/indexer/events'
  _globals['_FUNDINGUPDATEV1'].fields_by_name['funding_index']._loaded_options = None
  _globals['_FUNDINGUPDATEV1'].fields_by_name['funding_index']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_FUNDINGEVENTV1'].fields_by_name['updates']._loaded_options = None
  _globals['_FUNDINGEVENTV1'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_SOURCEOFFUNDS'].fields_by_name['address']._loaded_options = None
  _globals['_SOURCEOFFUNDS'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ORDERFILLEVENTV1'].fields_by_name['maker_order']._loaded_options = None
  _globals['_ORDERFILLEVENTV1'].fields_by_name['maker_order']._serialized_options = b'\310\336\037\000'
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['liquidated']._loaded_options = None
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['liquidated']._serialized_options = b'\310\336\037\000'
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['offsetting']._loaded_options = None
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['offsetting']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONORDERV1'].fields_by_name['liquidated']._loaded_options = None
  _globals['_LIQUIDATIONORDERV1'].fields_by_name['liquidated']._serialized_options = b'\310\336\037\000'
  _globals['_STATEFULORDEREVENTV1'].fields_by_name['order_place']._loaded_options = None
  _globals['_STATEFULORDEREVENTV1'].fields_by_name['order_place']._serialized_options = b'\030\001'
  _globals['_PERPETUALMARKETCREATEEVENTV1']._loaded_options = None
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_options = b'\030\001'
  _globals['_LIQUIDITYTIERUPSERTEVENTV1'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIERUPSERTEVENTV1'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_ADDRESSTRADINGREWARD'].fields_by_name['denom_amount']._loaded_options = None
  _globals['_ADDRESSTRADINGREWARD'].fields_by_name['denom_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_OPENINTERESTUPDATE'].fields_by_name['open_interest']._loaded_options = None
  _globals['_OPENINTERESTUPDATE'].fields_by_name['open_interest']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIQUIDITYTIERUPSERTEVENTV2'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIERUPSERTEVENTV2'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_FUNDINGUPDATEV1']._serialized_start=319
  _globals['_FUNDINGUPDATEV1']._serialized_end=482
  _globals['_FUNDINGEVENTV1']._serialized_start=485
  _globals['_FUNDINGEVENTV1']._serialized_end=745
  _globals['_FUNDINGEVENTV1_TYPE']._serialized_start=636
  _globals['_FUNDINGEVENTV1_TYPE']._serialized_end=745
  _globals['_MARKETEVENTV1']._serialized_start=748
  _globals['_MARKETEVENTV1']._serialized_end=1020
  _globals['_MARKETPRICEUPDATEEVENTV1']._serialized_start=1022
  _globals['_MARKETPRICEUPDATEEVENTV1']._serialized_end=1077
  _globals['_MARKETBASEEVENTV1']._serialized_start=1079
  _globals['_MARKETBASEEVENTV1']._serialized_end=1142
  _globals['_MARKETCREATEEVENTV1']._serialized_start=1144
  _globals['_MARKETCREATEEVENTV1']._serialized_end=1245
  _globals['_MARKETMODIFYEVENTV1']._serialized_start=1247
  _globals['_MARKETMODIFYEVENTV1']._serialized_end=1330
  _globals['_SOURCEOFFUNDS']._serialized_start=1333
  _globals['_SOURCEOFFUNDS']._serialized_end=1483
  _globals['_TRANSFEREVENTV1']._serialized_start=1486
  _globals['_TRANSFEREVENTV1']._serialized_end=1833
  _globals['_ORDERFILLEVENTV1']._serialized_start=1836
  _globals['_ORDERFILLEVENTV1']._serialized_end=2202
  _globals['_DELEVERAGINGEVENTV1']._serialized_start=2205
  _globals['_DELEVERAGINGEVENTV1']._serialized_end=2506
  _globals['_LIQUIDATIONORDERV1']._serialized_start=2509
  _globals['_LIQUIDATIONORDERV1']._serialized_end=2708
  _globals['_SUBACCOUNTUPDATEEVENTV1']._serialized_start=2711
  _globals['_SUBACCOUNTUPDATEEVENTV1']._serialized_end=3006
  _globals['_STATEFULORDEREVENTV1']._serialized_start=3009
  _globals['_STATEFULORDEREVENTV1']._serialized_end=4429
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERPLACEMENTV1']._serialized_start=3691
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERPLACEMENTV1']._serialized_end=3780
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERREMOVALV1']._serialized_start=3783
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERREMOVALV1']._serialized_end=3948
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERPLACEMENTV1']._serialized_start=3950
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERPLACEMENTV1']._serialized_end=4042
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERTRIGGEREDV1']._serialized_start=4044
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERTRIGGEREDV1']._serialized_end=4151
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERPLACEMENTV1']._serialized_start=4153
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERPLACEMENTV1']._serialized_end=4242
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERREPLACEMENTV1']._serialized_start=4245
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERREPLACEMENTV1']._serialized_end=4408
  _globals['_ASSETCREATEEVENTV1']._serialized_start=4431
  _globals['_ASSETCREATEEVENTV1']._serialized_end=4545
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_start=4548
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_end=4860
  _globals['_PERPETUALMARKETCREATEEVENTV2']._serialized_start=4863
  _globals['_PERPETUALMARKETCREATEEVENTV2']._serialized_end=5247
  _globals['_LIQUIDITYTIERUPSERTEVENTV1']._serialized_start=5250
  _globals['_LIQUIDITYTIERUPSERTEVENTV1']._serialized_end=5464
  _globals['_UPDATECLOBPAIREVENTV1']._serialized_start=5467
  _globals['_UPDATECLOBPAIREVENTV1']._serialized_end=5670
  _globals['_UPDATEPERPETUALEVENTV1']._serialized_start=5672
  _globals['_UPDATEPERPETUALEVENTV1']._serialized_end=5794
  _globals['_TRADINGREWARDSEVENTV1']._serialized_start=5796
  _globals['_TRADINGREWARDSEVENTV1']._serialized_end=5895
  _globals['_ADDRESSTRADINGREWARD']._serialized_start=5898
  _globals['_ADDRESSTRADINGREWARD']._serialized_end=6031
  _globals['_OPENINTERESTUPDATEEVENTV1']._serialized_start=6033
  _globals['_OPENINTERESTUPDATEEVENTV1']._serialized_end=6140
  _globals['_OPENINTERESTUPDATE']._serialized_start=6143
  _globals['_OPENINTERESTUPDATE']._serialized_end=6282
  _globals['_LIQUIDITYTIERUPSERTEVENTV2']._serialized_start=6285
  _globals['_LIQUIDITYTIERUPSERTEVENTV2']._serialized_end=6503
# @@protoc_insertion_point(module_scope)
